import os

from evote.settings import *  # noqa


DEBUG = False
TEMPLATE_DEBUG = True
COMPRESS_OFFLINE = True


ALLOWED_HOSTS = ['evote.dev.eurotux.com']

SECRET_KEY = os.environ.get('SECRET_KEY')

MIDDLEWARE_CLASSES += (  # noqa
    'django.middleware.gzip.GZipMiddleware',
)

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.mysql',
        'NAME': "evote",
        'USER': os.environ.get('MYSQL_USER'),
        'PASSWORD': os.environ.get('MYSQL_PASSWORD'),
        'HOST': os.environ.get('MYSQL_HOST'),
        'PORT': '',
        'OPTIONS': {
            'init_command': 'SET storage_engine=INNODB'
        },
    }
}

CACHES = {
    "default": {
        "BACKEND": "django_redis.cache.RedisCache",
        "LOCATION": "redis://127.0.0.1:6379/0",
        "KEY_PREFIX": "evote",
        "OPTIONS": {
            "CLIENT_CLASS": "django_redis.client.DefaultClient",
        }
    }
}


# Define the Queue Settings

BROKER_URL = os.environ.get('BROKER_URL')


# sorl thumbnail settings

THUMBNAIL_REDIS_URL = "redis://127.0.0.1:6379/0"
THUMBNAIL_KVSTORE = "sorl.thumbnail.kvstores.redis_kvstore.KVStore"
THUMBNAIL_DUMMY = True


# Logging

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'handlers': {
        'mail_admins': {
            'level': 'ERROR',
            'class': 'django.utils.log.AdminEmailHandler',
            'include_html': True
        }
    },
    'loggers': {
        'django.request': {
            'handlers': ['mail_admins'],
            'level': 'ERROR',
            'propagate': True,
        },
    },
}

# Django Site identification
SITE_ID = 4
