from __future__ import unicode_literals

import six
import hashlib
import logging
from datetime import date

logger = logging.getLogger("django")


def documents_upload_to(instance, filename):
    today = date.today().strftime("%Y/%m/%d")
    return "documents/%s/%s" % (today, filename)


def images_upload_to(instance, filename):
    today = date.today().strftime("%Y/%m/%d")
    return "images/%s/%s" % (today, filename)


def compare_data(model_or_dict1, model_or_dict2, keys):
    """ """
    uhash1 = calculate_hash(model_or_dict1, keys)
    uhash2 = calculate_hash(model_or_dict2, keys)
    return uhash1 == uhash2


def calculate_hash(model_or_dict, keys):
    uhash = ""
    for key in keys:
        if isinstance(model_or_dict, dict):
            value = model_or_dict.get(key)
        else:
            value = getattr(model_or_dict, key)
        if value:
            if isinstance(value, six.string_types):
                uhash += str(value)
            else:
                uhash += repr(value)
    return hashlib.md5(uhash).hexdigest()
