from __future__ import unicode_literals

from json import dumps, loads

from django.conf import settings
from django.core.mail.message import EmailMultiAlternatives
from django.core.mail import get_connection


def serialize_email(email):
    """
    Serializes EmailMultiAlternatives to JSON to pass to Celery
    """
    json_obj = {
        'headers': email.extra_headers,
        'connection': settings.EMAIL_BACKEND,
        'from_email': email.from_email,
        'to': email.to,
        'bcc': email.bcc,
        'cc': email.cc,
        'reply_to': email.reply_to,
        'subject': email.subject,
        'body': email.body,
        'attachments': email.attachments,
        'alternatives': email.alternatives
    }

    return dumps(json_obj)


def deserialize_email(email):
    """
    Deserializes JSON to EmailMessage pass to Celery
    """
    email_json = loads(email)

    email_obj = EmailMultiAlternatives(
        headers=email_json.get('headers'),
        connection=get_connection(backend=email_json.get('connection')),
        from_email=email_json.get('from_email'),
        to=email_json.get('to'),
        bcc=email_json.get('bcc'),
        cc=email_json.get('cc'),
        reply_to=email_json.get('reply_to'),
        subject=email_json.get('subject', ''),
        body=email_json.get('body', ''),
        attachments=email_json.get('attachments'))

    for alternative in email_json.get('alternatives'):
        email_obj.attach_alternative(alternative[0], alternative[1])

    return email_obj


def get_chunks(message_list, n=None):
    """
    Separates list in chunks
    """
    if not n and hasattr(settings, 'CELERY_EMAIL_CHUNK_SIZE'):
        n = settings.CELERY_EMAIL_CHUNK_SIZE
    else:
        n = 3
    return [message_list[i:i + 3] for i in range(
        0, len(message_list), n)]
