from __future__ import unicode_literals

from django.utils.translation import ugettext_lazy as _
from django.utils.encoding import python_2_unicode_compatible
from django.conf import settings
from django.db import models

from django_extensions.db.models import TimeStampedModel


@python_2_unicode_compatible
class SecretEntry(TimeStampedModel):
    """ """
    class Identifier:
        VOTING_CERT = 0
        VALIDATOR_CERT = 1
        FILTER_CERT = 2
        ANON_CERT = 3
        COUNTER_CERT = 4
        ROOT_CERT = 5
        ROOT_PVT_KEY = 6
        VALIDATOR_PVT_KEY = 7
        VALIDATOR_PUB_KEY = 8
        VOTING_PVT_KEY = 9
        VOTING_PUB_KEY = 10
        ROOT_PVT_KEY = 11
        ROOT_PUB_KEY = 12

        choices = (
            (VOTING_CERT, "voting cert"),
            (VALIDATOR_CERT, "validator cert"),
            (FILTER_CERT, "filter cert"),
            (ANON_CERT, "anonymizer cert"),
            (COUNTER_CERT, "counter cert"),
            (ROOT_CERT, "root cert"),
            (ROOT_PVT_KEY, "root private key"),
            (VALIDATOR_PVT_KEY, "validator private key"),
            (VALIDATOR_PUB_KEY, "validator public key"),
            (VOTING_PVT_KEY, "voting cert private key"),
            (VOTING_PUB_KEY, "voting cert public key"),
            (ROOT_PVT_KEY, "root cert private key"),
            (ROOT_PUB_KEY, "root public key"),
        )

    user = models.ForeignKey(
        settings.AUTH_USER_MODEL, related_name='+', editable=False)
    identifier = models.PositiveSmallIntegerField(
        _("identifier"), choices=Identifier.choices, unique=True)
    body = models.TextField(_("body"))

    class Meta:
        verbose_name = _("Secret entry")
        verbose_name_plural = _("Secret entries")

    def __str__(self):
        return self.get_identifier_display()
