//Cripto-5.0.0

//Cripto 5.1.2
function getPublicKeyFromCertificate(pemCertificate) {
  try {
    x509Certificate = forge.pki.certificateFromPem(pemCertificate, true);

    currentTime = new Date();
    expiredCertificate = (x509Certificate.validity.notAfter < currentTime);
  }
  catch (error) {
    return {"errorCode": 2, "publicKey": null};
  }

  publicKey = x509Certificate.publicKey;

  if (publicKey != null) {
    pemPublicKey = forge.pki.publicKeyToPem(publicKey);
    if (!expiredCertificate) {
      return {"errorCode": null, "publicKey": pemPublicKey};
    }
    else if (expiredCertificate) {
      return {"errorCode": 1, "publicKey": pemPublicKey};
    }
  }
  else {
    return {"errorCode": 3, "publicKey": null};
  }
}

//Cripto 5.2.2
function encryptWithPublicKey(plaintext, pemCertificate) {
  result = getPublicKeyFromCertificate(pemCertificate);
  pemPublicKey = result["publicKey"];

  if (pemPublicKey !== null) {
    publicKey = forge.pki.publicKeyFromPem(pemPublicKey, true);
    ciphertext = publicKey.encrypt(plaintext, "RSA-OAEP");
    return forge.util.encode64(ciphertext);
  }

  return null;
}

//Cripto 5.3.2
function verifyCertificateChain(pemCertificate, rootPEMCertificate) {
  x509Certificate = forge.pki.certificateFromPem(pemCertificate);
  rootX509Certificate = forge.pki.certificateFromPem(rootPEMCertificate);

  caStore = forge.pki.createCaStore();
  caStore.addCertificate(rootPEMCertificate);

  chain = [x509Certificate, rootX509Certificate]

  try {
    forge.pki.verifyCertificateChain(caStore, chain);
    return true;
  }
  catch (error) {
    return false;
  }
}
