from __future__ import unicode_literals

from django.template import Context, Template
from django.test import RequestFactory

from evotevotings.management.forms import ManagementAuthenticationForm

from . import ManagementTestCase


class ManagementTagsTest(ManagementTestCase):

    def setUp(self):
        factory = RequestFactory()
        self.request = factory.get('/test/')

    def test_not_logged_as_responsible(self):
        self.request.session = {}
        template = Template(
            "{% load management_tags %}{% logged_as_responsible %}")
        rendered = template.render(Context({'request': self.request}))
        self.assertEqual(rendered, 'False')

    def test_not_logged_as_member(self):
        self.request.session = {}
        template = Template("{% load management_tags %}{% logged_as_member %}")
        rendered = template.render(Context({'request': self.request}))
        self.assertEqual(rendered, 'False')

    def test_logged_as_responsible(self):
        self.request.session = {
            'user_profile':
                ManagementAuthenticationForm.Profiles.INSTITUTIONAL_RESPONSIBLE
        }
        template = Template(
            "{% load management_tags %}{% logged_as_responsible %}")
        rendered = template.render(Context({'request': self.request}))
        self.assertEqual(rendered, 'True')

    def test_logged_as_member(self):
        self.request.session = {
            'user_profile':
                ManagementAuthenticationForm.Profiles.ELECTORAL_MEMBER
        }
        template = Template("{% load management_tags %}{% logged_as_member %}")
        rendered = template.render(Context({'request': self.request}))
        self.assertEqual(rendered, 'True')
