from __future__ import unicode_literals

from django.views.generic.base import RedirectView
from django.conf.urls import url
from django.conf import settings

from evoteusers.views import EvoteLogoutView

from .views import (ElectoralProcessListView, ElectoralProcessDetailView,
                    ElectoralActionView, ElectionListView,
                    ElectionDetailConfigsView, ElectionDetailCalendarView,
                    ElectionDetailCategoriesView, ElectionDetailRollsView,
                    ElectionDetailCandidatesView, ElectionDetailBulletinView,
                    LoginView, ElectoralProcessFormView,
                    ElectoralProcessMembersView, ElectoralProcessSummaryView,
                    ElectoralProcessConfirmationView,
                    ElectoralProcessElectionsView,
                    ElectoralProcessResponsibleView,
                    ElectoralRollDetailView, ElectoralRollPublishView,
                    PersonalDataView, ElectoralMemberRemoveView)

from .ajax import (ActionValidationAjaxView, ManageActionValidationAjaxView,
                   ElectoralMemberAddFormView, ElectoralMemberEditFormView,
                   ElectoralMemberVerifyView)


app_name = "management"


urlpatterns = [
    url(
        regex=r'^$',
        view=RedirectView.as_view(url=settings.LOGIN_REDIRECT_URL),
        name="index"
    ),
    url(
        regex=r'^login/$',
        view=LoginView.as_view(),
        name="login"
    ),
    url(
        regex=r'^logout/$',
        view=EvoteLogoutView.as_view(),
        name="logout"
    ),
    url(
        regex=r'^personaldata',
        view=PersonalDataView.as_view(),
        name="personal-data"
    ),
    url(
        regex=r'^electoralprocess/$',
        view=ElectoralProcessListView.as_view(),
        name="electoralprocess-list"
    ),
    url(
        regex=r'^electoralprocess/new/$',
        view=ElectoralProcessFormView.as_view(),
        name="electoralprocess-new"
    ),
    # slug rules are greedy, order of urls is important here
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/$',
        view=ElectoralProcessDetailView.as_view(),
        name="electoralprocess-detail"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/edit/$',
        view=ElectoralProcessFormView.as_view(),
        name="electoralprocess-edit"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/edit/elections/$',
        view=ElectoralProcessElectionsView.as_view(),
        name="electoralprocess-elections"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/members/$',
        view=ElectoralProcessMembersView.as_view(),
        name="electoralprocess-members"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/responsible/$',
        view=ElectoralProcessResponsibleView.as_view(),
        name="electoralprocess-responsible"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/summary/$',
        view=ElectoralProcessSummaryView.as_view(),
        name="electoralprocess-summary"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/confirmation/$',
        view=ElectoralProcessConfirmationView.as_view(),
        name="electoralprocess-confirmation"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/actions/$',
        view=ElectoralActionView.as_view(),
        name="electoralprocess-actions"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/elections/$',
        view=ElectionListView.as_view(),
        name="election-list"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/elections/'
              r'(?P<slug_election>[-\w]+)/configs/$',
        view=ElectionDetailConfigsView.as_view(),
        name="election-detail-configs"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/elections/'
              r'(?P<slug_election>[-\w]+)/calendar/$',
        view=ElectionDetailCalendarView.as_view(),
        name="election-detail-calendar"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/elections/'
              r'(?P<slug_election>[-\w]+)/categories/$',
        view=ElectionDetailCategoriesView.as_view(),
        name="election-detail-categories"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/elections/'
              r'(?P<slug_election>[-\w]+)/rolls/$',
        view=ElectionDetailRollsView.as_view(),
        name="election-detail-rolls"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/elections/'
              r'(?P<slug_election>[-\w]+)/candidates/$',
        view=ElectionDetailCandidatesView.as_view(),
        name="election-detail-candidates"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/elections/'
              r'(?P<slug_election>[-\w]+)/bulletin/$',
        view=ElectionDetailBulletinView.as_view(),
        name="election-detail-bulletin"
    ),
    url(
        regex=r'^electoralroll/(?P<slug>[-\w]+)/$',
        view=ElectoralRollDetailView.as_view(),
        name="electoralroll-detail"
    ),
    url(
        regex=r'^electoralroll/(?P<slug>[-\w]+)/publish/$',
        view=ElectoralRollPublishView.as_view(),
        name="electoralroll-publish"
    ),
]

# ajax urls
urlpatterns += [
    url(
        regex=r'^(?P<process_pk>\d+)/electoral-action/manage/validate/$',
        view=ManageActionValidationAjaxView.as_view(),
        name="manageaction-validate"
    ),
    url(
        regex=r'^(?P<process_pk>\d+)/electoral-action/validate/(?P<pk>\d+)/$',
        view=ActionValidationAjaxView.as_view(),
        name="action-validate"
    ),
    url(
        regex=r'^(?P<process_pk>\d+)/members/add/$',
        view=ElectoralMemberAddFormView.as_view(),
        name="electoralmember-add"
    ),
    url(
        regex=r'^(?P<process_pk>\d+)/members/(?P<pk>\d+)/edit/$',
        view=ElectoralMemberEditFormView.as_view(),
        name="electoralmember-edit"
    ),
    url(
        regex=r'^(?P<process_pk>\d+)/members/(?P<pk>\d+)/del/$',
        view=ElectoralMemberRemoveView.as_view(),
        name='electoralmember-remove'
    ),
    url(
        regex=r'^members/verify/$',
        view=ElectoralMemberVerifyView.as_view(),
        name='electoralmember-verify'
    )
]
