from django.utils import timezone
from django.apps import apps
from django.conf import settings

from dateutil.relativedelta import relativedelta
from evote.celery import app
from django_fsm import can_proceed


def get_electoral_process(pk):
    ElectoralProcess = apps.get_model('evoteprocesses.ElectoralProcess')  # noqa
    return ElectoralProcess.objects.get(pk=pk)


@app.task(ignore_result=True)
def publish_electoral_process(electoral_process_id):
    """ """
    electoral_process = get_electoral_process(electoral_process_id)
    if can_proceed(electoral_process.publish):
        electoral_process.publish()
        electoral_process.save()


@app.task(ignore_result=True)
def close_electoral_process(electoral_process_id):
    """ """
    electoral_process = get_electoral_process(electoral_process_id)
    if can_proceed(electoral_process.close):
        electoral_process.close()
        electoral_process.save()
        archive_on = timezone.now() + \
            relativedelta(months=+settings.EVOTE_ARCHIVE_PROCESS_AFTER)
        archive_electoral_process.si(
            electoral_process_id).apply_async(eta=archive_on)


@app.task(ignore_result=True)
def archive_electoral_process(electoral_process_id):
    """ """
    electoral_process = get_electoral_process(electoral_process_id)
    if can_proceed(electoral_process.archive):
        electoral_process.archive()
        electoral_process.save()
