from __future__ import unicode_literals

from django.utils.translation import ugettext_lazy as _
from django.utils.encoding import python_2_unicode_compatible
from django.utils import timezone
from django.conf import settings
from django.db import models

from evotevotings.elections.models import Category, Election
from django_extensions.db.models import TimeStampedModel

from .managers import ElectionVoterManager


@python_2_unicode_compatible
class ElectionVoter(TimeStampedModel):
    """ """
    class VoteStatus:
        NO = 0
        YES = 1
        PENDING = 2

        choices = (
            (NO, _("Unsubmitted")),
            (YES, _("Submitted")),
            (PENDING, _("Submitting")),
        )

    user = models.ForeignKey(
        settings.AUTH_USER_MODEL, verbose_name=_("user"),
        on_delete=models.CASCADE, related_name="election_voters")
    election = models.ForeignKey(
        Election, verbose_name=_("election"), related_name="election_voters",
        on_delete=models.CASCADE)
    category = models.ForeignKey(
        Category, verbose_name=_("category"), related_name="election_voters",
        on_delete=models.CASCADE)
    name = models.CharField(_('name'), max_length=255, db_index=True)
    personnel_number = models.CharField(_('personnel number'), max_length=64,
                                        db_index=True)
    blind_vote_hash = models.CharField(
        _("blind user cyphered vote hash"),
        max_length=255,
        db_index=True,
        null=True)
    vote_status = models.PositiveSmallIntegerField(
        _("vote status"), choices=VoteStatus.choices,
        default=VoteStatus.NO)
    objects = ElectionVoterManager()

    class Meta:
        ordering = ('name',)
        verbose_name = _("voter")
        verbose_name_plural = _("voters")

    def __str__(self):
        return "{} ({})".format(self.name, self.personnel_number)

    @property
    def is_vote_available(self):
        """Checks if this ElectionVoter vote is still pending
           Can either be in PENDING after 2 minutes or
           in the NO status"""
        if(self.vote_status == self.VoteStatus.NO):
            return (0, True)
        if(self.vote_status == self.VoteStatus.YES):
            return (1, False)

        current_date = timezone.now()
        threshold = current_date - timezone.timedelta(minutes=2)
        available = self.modified < threshold

        if(available):
            return (0, True)
        else:
            return (2, False)
