/* globals jQuery, django, noty, Ladda, grecaptcha */
/******************************************************************
 * Site Name: eVote
 * Author: Luis Silva
 *
 * JavaScript: Main JavaScript (Initializations, etc...)
 *
 *****************************************************************/

"use strict";

(function($) {

    $.fn.submitOnChange = function()
    {
        return this.each(function()
        {
            var form = $(this);

            form.on('change', ":input", function() {
                form.submit();
            });
        });
    };

    $.fileUpload = function(selector)
    {
        $(document).on('click', selector, function(e)
        {
            e.preventDefault();

            var $this = $(this);
            var $inputfile = $this.find("input[type='file']");
            var $inputname = $this.find("input[data-upload-name]");

            $inputfile.on('click', function (e) {
                e.stopImmediatePropagation();
            });
            $inputfile.on('change', function(){
                var filename = $inputfile.val().split('\\').pop();
                $inputname.val(filename);
            });
            $inputfile.trigger('click');
        });
    };

    $.fn.sortableInit = function (selector, options)
    {
        var defaults = {
            axis: "y",
            opacity: 0.6,
            revert: true,
            start: function (e, ui) {
                var num = ui.placeholder.find('> *').length,
                    height = ui.helper.outerHeight(true);
                ui.placeholder.empty().html("<td colspan='" + num + "'></td>").css("height", height + "px");
            }
        };

        var opts = $.extend({}, defaults, options);

        return this.each(function() {
            var $this = $(this);

            if ($this.find("[data-handle]").length) {
                opts.handle = "[data-handle]";
            }

            $this.sortable(opts).disableSelection();
        });
    };

    $.evoteSettings = function evoteSettings() {

        /*
         * Define specific defaults for noty plugin for eVote project
         * http://ned.im/noty/
         */
        (function notyInit() {
            $.noty.defaults.timeout = 5000;
            $.noty.defaults.theme = 'evoteTheme';
            $.noty.defaults.layout = 'topCenter';
            $.noty.defaults.animation = {
                open: 'animated fadeIn',
                close: 'animated fadeOut',
            };
        })();

        /*
         * Define specific defaults and instantiate a djangoAjaxForms plugin for eVote project
         * /static/js/forms.jquery.js
         */
        (function djangoAjaxFormsInit() {
            $.fn.djangoAjaxForms.defaults.onFailFn = function onFailFn() {
                noty({
                    text: django.gettext("It was not possible submit form."),
                    type: "error"
                });
            };
            $.fn.djangoAjaxForms.defaults.onFieldErrorFn = function onFieldErrorFn() {
                if (typeof grecaptcha !== 'undefined'){
                    grecaptcha.reset();
                }
                noty({
                    text: django.gettext("Fix the errors on the form and resubmit the form"),
                    type: "warning"
                });
            };
            $.fn.djangoAjaxForms.defaults.onNonFieldErrorFn = function onNonFieldErrorFn(errors) {
                noty({
                    text: errors,
                    type: "warning"
                });
            };
            $.fn.djangoAjaxForms.defaults.onSubmit = function onSubmit($form) {
                Ladda.create( $form.find("[type=submit]").get(0) ).start();
            };

            $.fn.djangoAjaxForms.defaults.onBeforeSubmit = function onBeforeSubmit($form) {
                // if there's sortable rows on the form, update the order value
                $form.find("[data-sortable] > *").each(function (index) {
                    $(this).find("[name$='order']").val(index + 1);
                });
            };
            $.fn.djangoAjaxForms.defaults.onSubmitDone = function onSubmitDone() {
                Ladda.stopAll();
            };
        })();
    };


    var DROPDOWNS = (function() {

        var self = {
            menus: '.pure-menu-children',
            item : '.pure-menu-list a[data-type="menu"]',
            close: '.pure-menu-children .close-menu',
            elem : '<div class="selected-menu"></div>',

            dropdownInit: function dropdownInit() {
                /*$(self.menus).appendTo('body');*/
            },

            bindEvents: function bindEvents() {
                $(document).on('click', self.close, function (e) {
                    e.preventDefault();
                    $(self.item).find('.selected-menu').remove();
                    $(self.menus).hide();
                });
                $(document).click(function() {
                    $(self.item).find('.selected-menu').remove();
                    $(self.menus).hide();
                });
                $(document).on('click', self.menus, function (e) {
                    e.stopPropagation();
                    e.preventDefault();
                });
                $(document).on('click', self.item, function (e) {
                    e.preventDefault();
                    e.stopPropagation();
                    var menu = $(this).data('menu');
                    $(self.item).find('.selected-menu').remove();
                    $(this).append(self.elem);
                    $(self.menus).hide();
                    $("ul[data-menu='" + menu +"']").show();
                });
            },

            initialize: function initialize() {
                self.dropdownInit();
                self.bindEvents();
            }
        };
        return self;
    })();


    var ACCESSIBILITY = (function() {

        var self = {
            // Color vars
            color_storage: 'ACCESS_COLOR',
            color_class  : 'access-color',
            access_color : 'box-color2',
            change_color : 'div[data-box="color"]',
            // Text vars
            text_storage : 'ACCESS_TEXT',
            text_class   : 'access-text',
            access_text  : 'box-large',
            change_text  : 'div[data-box="text"]',

            init: function init() {
                self.initAccessibility(self.color_storage, self.color_class,
                                       self.change_color, self.access_color);
                self.initAccessibility(self.text_storage, self.text_class,
                                       self.change_text, self.access_text);
            },

            initAccessibility: function initAccessibility(storage, item_class, change, access) {
                var is_storage = localStorage[storage];
                if (is_storage) {
                    $('body').addClass(item_class);
                    $(change).removeClass('selected');
                    $(change+'.'+access).addClass('selected');
                }
            },

            selectOption: function selectOption(selector, change, access, storage, item_class) {
                if ( !$(selector).hasClass('selected') ) {
                    $(change).removeClass('selected');
                    $(selector).addClass('selected');
                    if ( $(selector).hasClass(access) ) {
                        localStorage[storage] = "yes";
                        $('body').addClass(item_class);
                    } else {
                        localStorage[storage] = "";
                        $('body').removeClass(item_class);
                    }
                }
            },

            bindEvents: function bindEvents() {
                $(document).on('click', self.change_color, function (e) {
                    e.preventDefault();
                    self.selectOption(this, self.change_color, self.access_color,
                                      self.color_storage, self.color_class);
                });

                $(document).on('click', self.change_text, function (e) {
                    e.preventDefault();
                    self.selectOption(this, self.change_text, self.access_text,
                                      self.text_storage, self.text_class);
                });
            },

            initialize: function initialize() {
                self.init();
                self.bindEvents();
            }
        };
        return self;
    })();

    var ACCORDION = (function() {

        var self = {
            acc_title: '.pure-sec-accordion .pure-sec-title',
            acc_body : '.pure-sec-accordion .pure-sec-body',

            bindEvents: function bindEvents() {
                $(document).on('click', self.acc_title, function (e) {
                    e.preventDefault();
                    $(this).find('i.ev-icon').toggleClass('evi-sel-drk-dwn').toggleClass('evi-sel-drk-up');
                    $(this).next(self.acc_body).slideToggle();
                });

                // Controls open on hash found
                var hash = window.location.hash;
                if (hash){
                    var element = $(hash);
                    element.find('.pure-sec-title i.ev-icon').toggleClass('evi-sel-drk-dwn').toggleClass('evi-sel-drk-up');
                    element.find(".pure-sec-body").slideToggle();
                }
            },

            initialize: function initialize() {
                self.bindEvents();
            }
        };
        return self;
    })();

    $(document).ready(function() {

        $.evoteSettings();

        //Instantiate select2 plugin for eVote project https://select2.github.io/
        $('select[data-style-select]').select2({
            minimumResultsForSearch: Infinity
        });
        $('select[data-style-select-search]').select2();

        // instantiate datetimepicker http://trentrichardson.com/examples/timepicker
        $('[data-datepicker]').datepicker({
            dateFormat: 'dd-mm-yy',
        });
        $('[data-datetimepicker]').datetimepicker({
            dateFormat: 'dd-mm-yy',
            timeFormat: 'HH:mm',
            stepMinute: 5,
            showTime: false
        });

        // django forms instantion
        $("form[data-ajax-submit]").djangoAjaxForms();

        // automatically submit form on input change
        $("form[data-submit-onchange]").submitOnChange();

        // transform django messages into noty notifications
        $('.noty-messages').djangoMessagesNoty();

        // Remodal instantiation
        $('[data-remodal-id]').remodal();

        // Formset initialize
        $("[data-formset]").formset({
            animateForms: true
        });

        $("[data-formset]").on('formAdded', function () {
            $(this).find("[data-formset]").formset({
                animateForms: true
            });
        });

        $("[data-sortable]").sortableInit();

        // infinite scroll
        if ($.fn.jscroll) {
            $("[data-jscroll]").jscroll({
                nextSelector: '[data-jscroll-next]'
            });
        }

        //
        $("[href='#']").on("click", function(e) {
            e.preventDefault();
        });

        $.fileUpload(".pure-field.clearablefileinput, .pure-field.fileinput, [data-upload]");


        ACCESSIBILITY.initialize();
        DROPDOWNS.initialize();
        ACCORDION.initialize();


        // Removal modals
        var confirmModal = $("[data-remodal-id='modalConfirmOP']").remodal({'closeOnCancel': true});
        $(document).on('click', "[data-remodal-target='modalConfirmOP']", function(e){
            e.preventDefault();
            var elem = $(this);

            $(document).on('confirmation', confirmModal, function(){
                window.location.href = elem.attr('href');
            });
        });


        // Print function
        $('.print-btn').on('click', function(){
            window.print();
        });
    });

})(jQuery);
